"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.gateway_pb2
import yandex.cloud.vpc.v1.gateway_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class GatewayServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.GetGatewayRequest,
        yandex.cloud.vpc.v1.gateway_pb2.Gateway,
    ]
    """Returns the specified Gateway resource.

    To get the list of all available Gateway resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewaysRequest,
        yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewaysResponse,
    ]
    """Retrieves the list of Gateway resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.CreateGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a gateway in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.UpdateGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified gateway."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.DeleteGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified gateway."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewayOperationsRequest,
        yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewayOperationsResponse,
    ]
    """List operations for the specified gateway."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.MoveGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move a gateway to another folder"""

class GatewayServiceAsyncStub:
    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.GetGatewayRequest,
        yandex.cloud.vpc.v1.gateway_pb2.Gateway,
    ]
    """Returns the specified Gateway resource.

    To get the list of all available Gateway resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewaysRequest,
        yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewaysResponse,
    ]
    """Retrieves the list of Gateway resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.CreateGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a gateway in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.UpdateGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified gateway."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.DeleteGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified gateway."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewayOperationsRequest,
        yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewayOperationsResponse,
    ]
    """List operations for the specified gateway."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.gateway_service_pb2.MoveGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move a gateway to another folder"""

class GatewayServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.vpc.v1.gateway_service_pb2.GetGatewayRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.gateway_pb2.Gateway, collections.abc.Awaitable[yandex.cloud.vpc.v1.gateway_pb2.Gateway]]:
        """Returns the specified Gateway resource.

        To get the list of all available Gateway resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewaysRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewaysResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewaysResponse]]:
        """Retrieves the list of Gateway resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.vpc.v1.gateway_service_pb2.CreateGatewayRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a gateway in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.vpc.v1.gateway_service_pb2.UpdateGatewayRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified gateway."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.vpc.v1.gateway_service_pb2.DeleteGatewayRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified gateway."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewayOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewayOperationsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.gateway_service_pb2.ListGatewayOperationsResponse]]:
        """List operations for the specified gateway."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.vpc.v1.gateway_service_pb2.MoveGatewayRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Move a gateway to another folder"""

def add_GatewayServiceServicer_to_server(servicer: GatewayServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ObjectStorage(google.protobuf.message.Message):
    """Reference to a file stored in Object Storage."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    """Bucket name."""
    name: builtins.str
    """File name."""
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket", b"bucket", "name", b"name"]) -> None: ...

global___ObjectStorage = ObjectStorage



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.mdb.postgresql.v1.perf_diag_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListRawStatementsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    FROM_TIME_FIELD_NUMBER: builtins.int
    TO_TIME_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of a PostgreSQL cluster to request query statistics for.

    To get a PostgreSQL cluster ID, use the [ClusterService.List] method.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of the results is larger than [page_size], the service returns [ListRawStatementsResponse.next_page_token]. You can use it to get the next page of the results in subsequent requests."""
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListRawStatementsResponse.next_page_token] returned by the previous SQL statement list request."""
    @property
    def from_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Beginning of the period for which you need to request data (in the [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format)."""

    @property
    def to_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End of the period for which you need to request data (in the [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format)."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        from_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        to_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_time", b"from_time", "to_time", b"to_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "from_time", b"from_time", "page_size", b"page_size", "page_token", b"page_token", "to_time", b"to_time"]) -> None: ...

global___ListRawStatementsRequest = ListRawStatementsRequest

@typing.final
class ListRawSessionStatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    FROM_TIME_FIELD_NUMBER: builtins.int
    TO_TIME_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of a PostgreSQL cluster to request session statistics for.

    To get a PostgreSQL cluster ID, use the [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of the results is larger than [page_size], the service returns [ListRawSessionStatesResponse.next_page_token]. You can use it to get the next page of the results in subsequent requests."""
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListRawSessionStatesResponse.next_page_token] returned by the previous PostgreSQL session list request."""
    @property
    def from_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Beginning of the period for which you need to request data (in the [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format)."""

    @property
    def to_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End of the period for which you need to request data (in the [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format)."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        from_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        to_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_time", b"from_time", "to_time", b"to_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "from_time", b"from_time", "page_size", b"page_size", "page_token", b"page_token", "to_time", b"to_time"]) -> None: ...

global___ListRawSessionStatesRequest = ListRawSessionStatesRequest

@typing.final
class ListRawSessionStatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_STATES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results when requesting the PostgreSQL session list. If the number of the results is larger than [ListRawSessionStatesRequest.page_size], use the [next_page_token] as the value for the [ListRawSessionStatesRequest.page_token] parameter in the next request. Each subsequent request will have its own [next_page_token] to continue paging through the results."""
    @property
    def session_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.postgresql.v1.perf_diag_pb2.SessionState]:
        """List of PostgreSQL sessions."""

    def __init__(
        self,
        *,
        session_states: collections.abc.Iterable[yandex.cloud.mdb.postgresql.v1.perf_diag_pb2.SessionState] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "session_states", b"session_states"]) -> None: ...

global___ListRawSessionStatesResponse = ListRawSessionStatesResponse

@typing.final
class ListRawStatementsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATEMENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results when requesting the PostgreSQL session list. If the number of the results is larger than [ListRawStatementsRequest.page_size], use the [next_page_token] as the value for the [ListRawStatementsRequest.page_token] parameter in the next request. Each subsequent request will have its own [next_page_token] to continue paging through the results."""
    @property
    def statements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.postgresql.v1.perf_diag_pb2.QueryStatement]:
        """List of SQL statements (queries)."""

    def __init__(
        self,
        *,
        statements: collections.abc.Iterable[yandex.cloud.mdb.postgresql.v1.perf_diag_pb2.QueryStatement] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "statements", b"statements"]) -> None: ...

global___ListRawStatementsResponse = ListRawStatementsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.assistants.v1.searchindex.search_index_file_pb2
import yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SearchIndexFileServiceStub:
    """ThreadService provides operations for managing files within search indexes."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2.GetSearchIndexFileRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_file_pb2.SearchIndexFile,
    ]
    """Retrieves details of a specific file that has been indexed within a search index."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2.ListSearchIndexFilesRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2.ListSearchIndexFilesResponse,
    ]
    """List files that are indexed within a specific search index."""

class SearchIndexFileServiceAsyncStub:
    """ThreadService provides operations for managing files within search indexes."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2.GetSearchIndexFileRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_file_pb2.SearchIndexFile,
    ]
    """Retrieves details of a specific file that has been indexed within a search index."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2.ListSearchIndexFilesRequest,
        yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2.ListSearchIndexFilesResponse,
    ]
    """List files that are indexed within a specific search index."""

class SearchIndexFileServiceServicer(metaclass=abc.ABCMeta):
    """ThreadService provides operations for managing files within search indexes."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2.GetSearchIndexFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.searchindex.search_index_file_pb2.SearchIndexFile, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.searchindex.search_index_file_pb2.SearchIndexFile]]:
        """Retrieves details of a specific file that has been indexed within a search index."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2.ListSearchIndexFilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2.ListSearchIndexFilesResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.searchindex.search_index_file_service_pb2.ListSearchIndexFilesResponse]]:
        """List files that are indexed within a specific search index."""

def add_SearchIndexFileServiceServicer_to_server(servicer: SearchIndexFileServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.ai.assistants.v1.threads import message_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2
from yandex.cloud.ai.assistants.v1.threads import message_service_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__service__pb2


class MessageServiceStub(object):
    """MessageService provides operations for managing messages.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.ai.assistants.v1.threads.MessageService/Create',
                request_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__service__pb2.CreateMessageRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2.Message.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.ai.assistants.v1.threads.MessageService/Get',
                request_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__service__pb2.GetMessageRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2.Message.FromString,
                )
        self.List = channel.unary_stream(
                '/yandex.cloud.ai.assistants.v1.threads.MessageService/List',
                request_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__service__pb2.ListMessagesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2.Message.FromString,
                )


class MessageServiceServicer(object):
    """MessageService provides operations for managing messages.
    """

    def Create(self, request, context):
        """Create a new message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Retrieve details of a specific message by its ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """List messages in a specific thread.
        By default, messages are listed in reverse chronological order, i.e., from the newest to the oldest.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MessageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__service__pb2.CreateMessageRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2.Message.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__service__pb2.GetMessageRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2.Message.SerializeToString,
            ),
            'List': grpc.unary_stream_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__service__pb2.ListMessagesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2.Message.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.assistants.v1.threads.MessageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MessageService(object):
    """MessageService provides operations for managing messages.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.assistants.v1.threads.MessageService/Create',
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__service__pb2.CreateMessageRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2.Message.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.assistants.v1.threads.MessageService/Get',
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__service__pb2.GetMessageRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2.Message.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.ai.assistants.v1.threads.MessageService/List',
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__service__pb2.ListMessagesRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2.Message.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Sink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class Yds(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STREAM_NAME_FIELD_NUMBER: builtins.int
        stream_name: builtins.str
        """Fully qualified name of data stream"""
        def __init__(
            self,
            *,
            stream_name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["stream_name", b"stream_name"]) -> None: ...

    @typing.final
    class S3(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BUCKET_FIELD_NUMBER: builtins.int
        PREFIX_FIELD_NUMBER: builtins.int
        bucket: builtins.str
        """Object storage bucket"""
        prefix: builtins.str
        """Prefix to use for saved log object names"""
        def __init__(
            self,
            *,
            bucket: builtins.str = ...,
            prefix: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["bucket", b"bucket", "prefix", b"prefix"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    YDS_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Sink ID."""
    folder_id: builtins.str
    """Sink folder ID."""
    cloud_id: builtins.str
    """Sink cloud ID."""
    name: builtins.str
    """Sink name."""
    description: builtins.str
    """Sink description."""
    service_account_id: builtins.str
    """Logs will be written to the sink on behalf of this service account"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Sink creation time."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Sink labels."""

    @property
    def yds(self) -> global___Sink.Yds:
        """Yandex data stream"""

    @property
    def s3(self) -> global___Sink.S3:
        """Object storage"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        yds: global___Sink.Yds | None = ...,
        s3: global___Sink.S3 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "s3", b"s3", "sink", b"sink", "yds", b"yds"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "s3", b"s3", "service_account_id", b"service_account_id", "sink", b"sink", "yds", b"yds"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["sink", b"sink"]) -> typing.Literal["yds", "s3"] | None: ...

global___Sink = Sink



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tuning/v1/tuning_types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/ai/tuning/v1/tuning_types.proto\x12\x19yandex.cloud.ai.tuning.v1\"S\n\x0eTuningTypeLora\x12\x0c\n\x04rank\x18\x01 \x01(\x03\x12\r\n\x05\x61lpha\x18\x02 \x01(\x01\x12\x16\n\x0einitialization\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\".\n\x14TuningTypePromptTune\x12\x16\n\x0evirtual_tokens\x18\x01 \x01(\x03\x42\x63\n\x1dyandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tuning.v1.tuning_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomo'
  _globals['_TUNINGTYPELORA']._serialized_start=75
  _globals['_TUNINGTYPELORA']._serialized_end=158
  _globals['_TUNINGTYPEPROMPTTUNE']._serialized_start=160
  _globals['_TUNINGTYPEPROMPTTUNE']._serialized_end=206
# @@protoc_insertion_point(module_scope)



from typing import TYPE_CHECKING, Generic, Optional, TypeVar

if TYPE_CHECKING:
    import google.protobuf.message

    from yandex.cloud.operation.operation_pb2 import Operation


RequestType = TypeVar("RequestType", bound="google.protobuf.message.Message")  # pylint: disable=C0103
ResponseType = TypeVar("ResponseType", bound="google.protobuf.message.Message")  # pylint: disable=C0103
MetaType = TypeVar("MetaType", bound="google.protobuf.message.Message")  # pylint: disable=C0103


class OperationResult(Generic[ResponseType, MetaType]):
    def __init__(
        self,
        operation: "Operation",
        response: Optional["ResponseType"] = None,
        meta: Optional["MetaType"] = None,
    ):
        self.operation = operation
        self.response = response
        self.meta = meta


class OperationError(RuntimeError):
    def __init__(self, message: str, operation_result: OperationResult[ResponseType, MetaType]):
        super(OperationError, self).__init__(message)  # pylint: disable=super-with-arguments
        self.message = message
        self.operation_result = operation_result



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TextClassificationServiceStub:
    """Service for classifying the text requests provided in prompts."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Classify: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.TextClassificationRequest,
        yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.TextClassificationResponse,
    ]
    """RPC method to classify text with tuned model.

    The names of the classes between which the model will be distributing requests 
    must be specified during model tuning and are not provided in the request.
    """

    FewShotClassify: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.FewShotTextClassificationRequest,
        yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.FewShotTextClassificationResponse,
    ]
    """RPC method for binary and multi-class classification. 

    You can provide up to 20 classes for few-shot text classification
    with optional examples.
    """

class TextClassificationServiceAsyncStub:
    """Service for classifying the text requests provided in prompts."""

    Classify: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.TextClassificationRequest,
        yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.TextClassificationResponse,
    ]
    """RPC method to classify text with tuned model.

    The names of the classes between which the model will be distributing requests 
    must be specified during model tuning and are not provided in the request.
    """

    FewShotClassify: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.FewShotTextClassificationRequest,
        yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.FewShotTextClassificationResponse,
    ]
    """RPC method for binary and multi-class classification. 

    You can provide up to 20 classes for few-shot text classification
    with optional examples.
    """

class TextClassificationServiceServicer(metaclass=abc.ABCMeta):
    """Service for classifying the text requests provided in prompts."""

    @abc.abstractmethod
    def Classify(
        self,
        request: yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.TextClassificationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.TextClassificationResponse, collections.abc.Awaitable[yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.TextClassificationResponse]]:
        """RPC method to classify text with tuned model.

        The names of the classes between which the model will be distributing requests 
        must be specified during model tuning and are not provided in the request.
        """

    @abc.abstractmethod
    def FewShotClassify(
        self,
        request: yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.FewShotTextClassificationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.FewShotTextClassificationResponse, collections.abc.Awaitable[yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_service_pb2.FewShotTextClassificationResponse]]:
        """RPC method for binary and multi-class classification. 

        You can provide up to 20 classes for few-shot text classification
        with optional examples.
        """

def add_TextClassificationServiceServicer_to_server(servicer: TextClassificationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ApiGateway(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ApiGateway._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: ApiGateway._Status.ValueType  # 0
        CREATING: ApiGateway._Status.ValueType  # 1
        """API gateway is being created."""
        ACTIVE: ApiGateway._Status.ValueType  # 2
        """API gateway is ready for use."""
        DELETING: ApiGateway._Status.ValueType  # 3
        """API gateway is being deleted."""
        ERROR: ApiGateway._Status.ValueType  # 4
        """API gateway failed. The only allowed action is delete."""
        UPDATING: ApiGateway._Status.ValueType  # 5
        """API gateway is being updated."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: ApiGateway.Status.ValueType  # 0
    CREATING: ApiGateway.Status.ValueType  # 1
    """API gateway is being created."""
    ACTIVE: ApiGateway.Status.ValueType  # 2
    """API gateway is ready for use."""
    DELETING: ApiGateway.Status.ValueType  # 3
    """API gateway is being deleted."""
    ERROR: ApiGateway.Status.ValueType  # 4
    """API gateway failed. The only allowed action is delete."""
    UPDATING: ApiGateway.Status.ValueType  # 5
    """API gateway is being updated."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class VariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___VariableInput: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___VariableInput | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    ATTACHED_DOMAINS_FIELD_NUMBER: builtins.int
    CONNECTIVITY_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    CANARY_FIELD_NUMBER: builtins.int
    EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the API gateway. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the API gateway belongs to."""
    name: builtins.str
    """Name of the API gateway. The name is unique within the folder."""
    description: builtins.str
    """Description of the API gateway."""
    status: global___ApiGateway.Status.ValueType
    """Status of the API gateway."""
    domain: builtins.str
    """Default domain for the API gateway. Generated at creation time."""
    log_group_id: builtins.str
    """ID of the log group for the API gateway."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the API-gateway."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """API gateway labels as `key:value` pairs."""

    @property
    def attached_domains(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AttachedDomain]:
        """List of domains attached to API gateway."""

    @property
    def connectivity(self) -> global___Connectivity:
        """Network access. If specified the gateway will be attached to specified network/subnet(s)."""

    @property
    def log_options(self) -> global___LogOptions:
        """Options for logging from the API gateway."""

    @property
    def variables(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___VariableInput]:
        """Values of variables defined in the specification."""

    @property
    def canary(self) -> global___Canary:
        """Canary release of the gateway."""

    @property
    def execution_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Timeout for gateway call execution"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___ApiGateway.Status.ValueType = ...,
        domain: builtins.str = ...,
        log_group_id: builtins.str = ...,
        attached_domains: collections.abc.Iterable[global___AttachedDomain] | None = ...,
        connectivity: global___Connectivity | None = ...,
        log_options: global___LogOptions | None = ...,
        variables: collections.abc.Mapping[builtins.str, global___VariableInput] | None = ...,
        canary: global___Canary | None = ...,
        execution_timeout: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["canary", b"canary", "connectivity", b"connectivity", "created_at", b"created_at", "execution_timeout", b"execution_timeout", "log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attached_domains", b"attached_domains", "canary", b"canary", "connectivity", b"connectivity", "created_at", b"created_at", "description", b"description", "domain", b"domain", "execution_timeout", b"execution_timeout", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "log_group_id", b"log_group_id", "log_options", b"log_options", "name", b"name", "status", b"status", "variables", b"variables"]) -> None: ...

global___ApiGateway = ApiGateway

@typing.final
class AttachedDomain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_ID_FIELD_NUMBER: builtins.int
    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    domain_id: builtins.str
    """ID of the domain."""
    certificate_id: builtins.str
    """ID of the domain certificate."""
    enabled: builtins.bool
    """Enabling flag."""
    domain: builtins.str
    """Name of the domain."""
    def __init__(
        self,
        *,
        domain_id: builtins.str = ...,
        certificate_id: builtins.str = ...,
        enabled: builtins.bool = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id", "domain", b"domain", "domain_id", b"domain_id", "enabled", b"enabled"]) -> None: ...

global___AttachedDomain = AttachedDomain

@typing.final
class Connectivity(google.protobuf.message.Message):
    """Gateway connectivity specification."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """Network the gateway will have access to.
    It's essential to specify network with subnets in all availability zones.
    """
    @property
    def subnet_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Complete list of subnets (from the same network) the gateway can be attached to.
        It's essential to specify at least one subnet for each availability zones.
        """

    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        subnet_id: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id", "subnet_id", b"subnet_id"]) -> None: ...

global___Connectivity = Connectivity

@typing.final
class LogOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    """Is logging from API gateway disabled."""
    log_group_id: builtins.str
    """Entry should be written to log group resolved by ID."""
    folder_id: builtins.str
    """Entry should be written to default log group for specified folder."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum log entry level.

    See [LogLevel.Level] for details.
    """
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "disabled", b"disabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___LogOptions = LogOptions

@typing.final
class Canary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class VariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___VariableInput: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___VariableInput | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    WEIGHT_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    weight: builtins.int
    """It describes percentage of requests, which will be processed by canary."""
    @property
    def variables(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___VariableInput]:
        """Values specification variables, associated with canary."""

    def __init__(
        self,
        *,
        weight: builtins.int = ...,
        variables: collections.abc.Mapping[builtins.str, global___VariableInput] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["variables", b"variables", "weight", b"weight"]) -> None: ...

global___Canary = Canary

@typing.final
class VariableInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRING_VALUE_FIELD_NUMBER: builtins.int
    INT_VALUE_FIELD_NUMBER: builtins.int
    DOUBLE_VALUE_FIELD_NUMBER: builtins.int
    BOOL_VALUE_FIELD_NUMBER: builtins.int
    string_value: builtins.str
    int_value: builtins.int
    double_value: builtins.float
    bool_value: builtins.bool
    def __init__(
        self,
        *,
        string_value: builtins.str = ...,
        int_value: builtins.int = ...,
        double_value: builtins.float = ...,
        bool_value: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bool_value", b"bool_value", "double_value", b"double_value", "int_value", b"int_value", "string_value", b"string_value", "variable_value", b"variable_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bool_value", b"bool_value", "double_value", b"double_value", "int_value", b"int_value", "string_value", b"string_value", "variable_value", b"variable_value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["variable_value", b"variable_value"]) -> typing.Literal["string_value", "int_value", "double_value", "bool_value"] | None: ...

global___VariableInput = VariableInput



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.analysis.statistics_common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InterruptsStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEAKER_INTERRUPTS_FIELD_NUMBER: builtins.int
    @property
    def speaker_interrupts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InterruptsEvaluation]:
        """Interrupts description for every speaker"""

    def __init__(
        self,
        *,
        speaker_interrupts: collections.abc.Iterable[global___InterruptsEvaluation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["speaker_interrupts", b"speaker_interrupts"]) -> None: ...

global___InterruptsStatistics = InterruptsStatistics

@typing.final
class InterruptsEvaluation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEAKER_TAG_FIELD_NUMBER: builtins.int
    INTERRUPTS_COUNT_FIELD_NUMBER: builtins.int
    INTERRUPTS_DURATION_MS_FIELD_NUMBER: builtins.int
    INTERRUPTS_FIELD_NUMBER: builtins.int
    INTERRUPTS_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    speaker_tag: builtins.str
    """Speaker tag"""
    interrupts_count: builtins.int
    """Number of interrupts made by the speaker"""
    interrupts_duration_ms: builtins.int
    """Total duration of all interrupts"""
    interrupts_duration_seconds: builtins.int
    """Total duration of all interrupts in seconds"""
    @property
    def interrupts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.AudioSegmentBoundaries]:
        """Boundaries for every interrupt"""

    def __init__(
        self,
        *,
        speaker_tag: builtins.str = ...,
        interrupts_count: builtins.int = ...,
        interrupts_duration_ms: builtins.int = ...,
        interrupts: collections.abc.Iterable[yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.AudioSegmentBoundaries] | None = ...,
        interrupts_duration_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["interrupts", b"interrupts", "interrupts_count", b"interrupts_count", "interrupts_duration_ms", b"interrupts_duration_ms", "interrupts_duration_seconds", b"interrupts_duration_seconds", "speaker_tag", b"speaker_tag"]) -> None: ...

global___InterruptsEvaluation = InterruptsEvaluation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Rule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Rule._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Rule._Status.ValueType  # 0
        CREATING: Rule._Status.ValueType  # 1
        """Rule creation in progress, rule is not enabled yet"""
        ENABLED: Rule._Status.ValueType  # 2
        """Rule is operating"""
        UPDATING: Rule._Status.ValueType  # 3
        """Rule update in progress, rule is disabled during update"""
        DISABLED: Rule._Status.ValueType  # 4
        """Rule is explicitly disabled by the user"""
        DELETING: Rule._Status.ValueType  # 5
        """Rule deletion in progress"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Rule.Status.ValueType  # 0
    CREATING: Rule.Status.ValueType  # 1
    """Rule creation in progress, rule is not enabled yet"""
    ENABLED: Rule.Status.ValueType  # 2
    """Rule is operating"""
    UPDATING: Rule.Status.ValueType  # 3
    """Rule update in progress, rule is disabled during update"""
    DISABLED: Rule.Status.ValueType  # 4
    """Rule is explicitly disabled by the user"""
    DELETING: Rule.Status.ValueType  # 5
    """Rule deletion in progress"""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    BUS_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the rule."""
    bus_id: builtins.str
    """ID of the bus that the rule belongs to."""
    folder_id: builtins.str
    """ID of the folder that the rule resides in."""
    cloud_id: builtins.str
    """ID of the cloud that the rule resides in."""
    name: builtins.str
    """Name of the rule."""
    description: builtins.str
    """Description of the rule."""
    deletion_protection: builtins.bool
    """Flag that disallow deletion of the rule."""
    status: global___Rule.Status.ValueType
    """Rule status"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def filter(self) -> global___Filter:
        """Filter for the rule."""

    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Target]:
        """Targets of the rule."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        bus_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        filter: global___Filter | None = ...,
        targets: collections.abc.Iterable[global___Target] | None = ...,
        deletion_protection: builtins.bool = ...,
        status: global___Rule.Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "cloud_id", b"cloud_id", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "filter", b"filter", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "status", b"status", "targets", b"targets"]) -> None: ...

global___Rule = Rule

@typing.final
class Filter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JQ_FILTER_FIELD_NUMBER: builtins.int
    jq_filter: builtins.str
    """JQ filter for matching events."""
    def __init__(
        self,
        *,
        jq_filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["condition", b"condition", "jq_filter", b"jq_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["condition", b"condition", "jq_filter", b"jq_filter"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["condition", b"condition"]) -> typing.Literal["jq_filter"] | None: ...

global___Filter = Filter

@typing.final
class Transformer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JQ_TRANSFORMER_FIELD_NUMBER: builtins.int
    jq_transformer: builtins.str
    """JQ string inrerpolation expression for changing event format."""
    def __init__(
        self,
        *,
        jq_transformer: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["jq_transformer", b"jq_transformer", "transformer", b"transformer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["jq_transformer", b"jq_transformer", "transformer", b"transformer"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["transformer", b"transformer"]) -> typing.Literal["jq_transformer"] | None: ...

global___Transformer = Transformer

@typing.final
class Target(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Target._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Target._Status.ValueType  # 0
        ENABLED: Target._Status.ValueType  # 1
        """Target is enabled."""
        DISABLED: Target._Status.ValueType  # 2
        """Target is disabled."""
        RESOURCE_NOT_FOUND: Target._Status.ValueType  # 3
        """Target does not exist."""
        PERMISSION_DENIED: Target._Status.ValueType  # 4
        """Service account does not have read permission on source."""
        SUBJECT_NOT_FOUND: Target._Status.ValueType  # 5
        """Service account not found."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Status of the target."""

    STATUS_UNSPECIFIED: Target.Status.ValueType  # 0
    ENABLED: Target.Status.ValueType  # 1
    """Target is enabled."""
    DISABLED: Target.Status.ValueType  # 2
    """Target is disabled."""
    RESOURCE_NOT_FOUND: Target.Status.ValueType  # 3
    """Target does not exist."""
    PERMISSION_DENIED: Target.Status.ValueType  # 4
    """Service account does not have read permission on source."""
    SUBJECT_NOT_FOUND: Target.Status.ValueType  # 5
    """Service account not found."""

    YDS_FIELD_NUMBER: builtins.int
    YMQ_FIELD_NUMBER: builtins.int
    FUNCTION_FIELD_NUMBER: builtins.int
    CONTAINER_FIELD_NUMBER: builtins.int
    GATEWAY_WS_BROADCAST_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    WORKFLOW_FIELD_NUMBER: builtins.int
    TRANSFORMER_FIELD_NUMBER: builtins.int
    RETRY_SETTINGS_FIELD_NUMBER: builtins.int
    DEAD_LETTER_QUEUE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    status: global___Target.Status.ValueType
    """Status of the target."""
    @property
    def yds(self) -> global___YdsTarget: ...
    @property
    def ymq(self) -> global___YmqTarget: ...
    @property
    def function(self) -> global___FunctionTarget: ...
    @property
    def container(self) -> global___ContainerTarget: ...
    @property
    def gateway_ws_broadcast(self) -> global___GatewayWebsocketBroadcastTarget: ...
    @property
    def logging(self) -> global___LoggingTarget: ...
    @property
    def workflow(self) -> global___WorkflowTarget: ...
    @property
    def transformer(self) -> global___Transformer:
        """Transformer of the target."""

    @property
    def retry_settings(self) -> global___RetrySettings:
        """Retry settings of the target."""

    @property
    def dead_letter_queue(self) -> global___PutQueueMessage:
        """Dead letter queue."""

    def __init__(
        self,
        *,
        yds: global___YdsTarget | None = ...,
        ymq: global___YmqTarget | None = ...,
        function: global___FunctionTarget | None = ...,
        container: global___ContainerTarget | None = ...,
        gateway_ws_broadcast: global___GatewayWebsocketBroadcastTarget | None = ...,
        logging: global___LoggingTarget | None = ...,
        workflow: global___WorkflowTarget | None = ...,
        transformer: global___Transformer | None = ...,
        retry_settings: global___RetrySettings | None = ...,
        dead_letter_queue: global___PutQueueMessage | None = ...,
        status: global___Target.Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["container", b"container", "dead_letter", b"dead_letter", "dead_letter_queue", b"dead_letter_queue", "function", b"function", "gateway_ws_broadcast", b"gateway_ws_broadcast", "logging", b"logging", "retry_settings", b"retry_settings", "target", b"target", "transformer", b"transformer", "workflow", b"workflow", "yds", b"yds", "ymq", b"ymq"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container", b"container", "dead_letter", b"dead_letter", "dead_letter_queue", b"dead_letter_queue", "function", b"function", "gateway_ws_broadcast", b"gateway_ws_broadcast", "logging", b"logging", "retry_settings", b"retry_settings", "status", b"status", "target", b"target", "transformer", b"transformer", "workflow", b"workflow", "yds", b"yds", "ymq", b"ymq"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["dead_letter", b"dead_letter"]) -> typing.Literal["dead_letter_queue"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["yds", "ymq", "function", "container", "gateway_ws_broadcast", "logging", "workflow"] | None: ...

global___Target = Target

@typing.final
class YdsTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    STREAM_NAME_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Stream database."""
    stream_name: builtins.str
    """Full stream name, like /ru-central1/aoegtvhtp8ob********/cc8004q4lbo6********/test."""
    service_account_id: builtins.str
    """Service account, which has write permission on the stream."""
    def __init__(
        self,
        *,
        database: builtins.str = ...,
        stream_name: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database", b"database", "service_account_id", b"service_account_id", "stream_name", b"stream_name"]) -> None: ...

global___YdsTarget = YdsTarget

@typing.final
class YmqTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUEUE_ARN_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    queue_arn: builtins.str
    """Queue ARN.
    Example: yrn:yc:ymq:ru-central1:aoe***:test
    """
    service_account_id: builtins.str
    """Service account which has write access to the queue."""
    def __init__(
        self,
        *,
        queue_arn: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["queue_arn", b"queue_arn", "service_account_id", b"service_account_id"]) -> None: ...

global___YmqTarget = YmqTarget

@typing.final
class FunctionTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    FUNCTION_TAG_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    BATCH_SETTINGS_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """Function ID."""
    function_tag: builtins.str
    """Function tag, optional."""
    service_account_id: builtins.str
    """Service account which has call permission on the function, optional."""
    @property
    def batch_settings(self) -> global___BatchSettings:
        """Batch settings."""

    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        function_tag: builtins.str = ...,
        service_account_id: builtins.str = ...,
        batch_settings: global___BatchSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["batch_settings", b"batch_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["batch_settings", b"batch_settings", "function_id", b"function_id", "function_tag", b"function_tag", "service_account_id", b"service_account_id"]) -> None: ...

global___FunctionTarget = FunctionTarget

@typing.final
class ContainerTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    CONTAINER_REVISION_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    BATCH_SETTINGS_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """Container ID."""
    container_revision_id: builtins.str
    """Container revision ID."""
    path: builtins.str
    """Endpoint HTTP path to invoke."""
    service_account_id: builtins.str
    """Service account which should be used to call a container, optional."""
    @property
    def batch_settings(self) -> global___BatchSettings:
        """Batch settings."""

    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        container_revision_id: builtins.str = ...,
        path: builtins.str = ...,
        service_account_id: builtins.str = ...,
        batch_settings: global___BatchSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["batch_settings", b"batch_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["batch_settings", b"batch_settings", "container_id", b"container_id", "container_revision_id", b"container_revision_id", "path", b"path", "service_account_id", b"service_account_id"]) -> None: ...

global___ContainerTarget = ContainerTarget

@typing.final
class GatewayWebsocketBroadcastTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    BATCH_SETTINGS_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    """Gateway ID."""
    path: builtins.str
    """Path."""
    service_account_id: builtins.str
    """Service account which has permission for writing to websockets."""
    @property
    def batch_settings(self) -> global___BatchSettings:
        """Batch settings."""

    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
        path: builtins.str = ...,
        service_account_id: builtins.str = ...,
        batch_settings: global___BatchSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["batch_settings", b"batch_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["batch_settings", b"batch_settings", "gateway_id", b"gateway_id", "path", b"path", "service_account_id", b"service_account_id"]) -> None: ...

global___GatewayWebsocketBroadcastTarget = GatewayWebsocketBroadcastTarget

@typing.final
class LoggingTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    folder_id: builtins.str
    service_account_id: builtins.str
    """Service account which has permission for writing logs."""
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "service_account_id", b"service_account_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___LoggingTarget = LoggingTarget

@typing.final
class WorkflowTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    BATCH_SETTINGS_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """Workflow ID."""
    service_account_id: builtins.str
    """SA which should be used to start workflow."""
    @property
    def batch_settings(self) -> global___BatchSettings:
        """Batch settings."""

    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
        batch_settings: global___BatchSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["batch_settings", b"batch_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["batch_settings", b"batch_settings", "service_account_id", b"service_account_id", "workflow_id", b"workflow_id"]) -> None: ...

global___WorkflowTarget = WorkflowTarget

@typing.final
class RetrySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETRY_ATTEMPTS_FIELD_NUMBER: builtins.int
    MAXIMUM_AGE_FIELD_NUMBER: builtins.int
    retry_attempts: builtins.int
    """Maximum number of retries (extra calls) before an action fails."""
    @property
    def maximum_age(self) -> google.protobuf.duration_pb2.Duration:
        """Event goes to dlq when its age exceeds this value. Default is 24h."""

    def __init__(
        self,
        *,
        retry_attempts: builtins.int = ...,
        maximum_age: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["maximum_age", b"maximum_age"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["maximum_age", b"maximum_age", "retry_attempts", b"retry_attempts"]) -> None: ...

global___RetrySettings = RetrySettings

@typing.final
class PutQueueMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUEUE_ARN_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    queue_arn: builtins.str
    """ID of the queue."""
    service_account_id: builtins.str
    """Service account which has write permission on the queue."""
    def __init__(
        self,
        *,
        queue_arn: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["queue_arn", b"queue_arn", "service_account_id", b"service_account_id"]) -> None: ...

global___PutQueueMessage = PutQueueMessage

@typing.final
class BatchSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_COUNT_FIELD_NUMBER: builtins.int
    MAX_BYTES_FIELD_NUMBER: builtins.int
    CUTOFF_FIELD_NUMBER: builtins.int
    max_count: builtins.int
    """Maximum batch size: trigger will send a batch if number of events exceeds this value."""
    max_bytes: builtins.int
    """Maximum batch size: trigger will send a batch if total size of events exceeds this value."""
    @property
    def cutoff(self) -> google.protobuf.duration_pb2.Duration:
        """Maximum batch size: trigger will send a batch if its lifetime exceeds this value."""

    def __init__(
        self,
        *,
        max_count: builtins.int = ...,
        max_bytes: builtins.int = ...,
        cutoff: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cutoff", b"cutoff"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cutoff", b"cutoff", "max_bytes", b"max_bytes", "max_count", b"max_count"]) -> None: ...

global___BatchSettings = BatchSettings



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/lockbox/v1/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/lockbox/v1/secret.proto\x12\x17yandex.cloud.lockbox.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xce\x04\n\x06Secret\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12;\n\x06labels\x18\x06 \x03(\x0b\x32+.yandex.cloud.lockbox.v1.Secret.LabelsEntry\x12\x12\n\nkms_key_id\x18\x07 \x01(\t\x12\x36\n\x06status\x18\x08 \x01(\x0e\x32&.yandex.cloud.lockbox.v1.Secret.Status\x12\x39\n\x0f\x63urrent_version\x18\t \x01(\x0b\x32 .yandex.cloud.lockbox.v1.Version\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12_\n\x1epassword_payload_specification\x18\x0b \x01(\x0b\x32\x35.yandex.cloud.lockbox.v1.PasswordPayloadSpecificationH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\x42\x17\n\x15payload_specification\"\xc8\x03\n\x07Version\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tsecret_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndestroy_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x37\n\x06status\x18\x06 \x01(\x0e\x32\'.yandex.cloud.lockbox.v1.Version.Status\x12\x1a\n\x12payload_entry_keys\x18\x07 \x03(\t\x12_\n\x1epassword_payload_specification\x18\x08 \x01(\x0b\x32\x35.yandex.cloud.lockbox.v1.PasswordPayloadSpecificationH\x00\"Z\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1d\n\x19SCHEDULED_FOR_DESTRUCTION\x10\x02\x12\r\n\tDESTROYED\x10\x03\x42\x17\n\x15payload_specification\"\xa0\x03\n\x1cPasswordPayloadSpecification\x12:\n\x0cpassword_key\x18\x01 \x01(\tB$\xe8\xc7\x31\x01\xf2\xc7\x31\x13[-_./\\\\@0-9a-zA-Z]+\x8a\xc8\x31\x05<=256\x12\x19\n\x06length\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05<=256\x12\x35\n\x11include_uppercase\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11include_lowercase\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0einclude_digits\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13include_punctuation\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12&\n\x14included_punctuation\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=32\x12&\n\x14\x65xcluded_punctuation\x18\x08 \x01(\tB\x08\x8a\xc8\x31\x04<=31Bb\n\x1byandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockboxb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.lockbox.v1.secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockbox'
  _SECRET_LABELSENTRY._options = None
  _SECRET_LABELSENTRY._serialized_options = b'8\001'
  _PASSWORDPAYLOADSPECIFICATION.fields_by_name['password_key']._options = None
  _PASSWORDPAYLOADSPECIFICATION.fields_by_name['password_key']._serialized_options = b'\350\3071\001\362\3071\023[-_./\\\\@0-9a-zA-Z]+\212\3101\005<=256'
  _PASSWORDPAYLOADSPECIFICATION.fields_by_name['length']._options = None
  _PASSWORDPAYLOADSPECIFICATION.fields_by_name['length']._serialized_options = b'\372\3071\005<=256'
  _PASSWORDPAYLOADSPECIFICATION.fields_by_name['included_punctuation']._options = None
  _PASSWORDPAYLOADSPECIFICATION.fields_by_name['included_punctuation']._serialized_options = b'\212\3101\004<=32'
  _PASSWORDPAYLOADSPECIFICATION.fields_by_name['excluded_punctuation']._options = None
  _PASSWORDPAYLOADSPECIFICATION.fields_by_name['excluded_punctuation']._serialized_options = b'\212\3101\004<=31'
  _globals['_SECRET']._serialized_start=162
  _globals['_SECRET']._serialized_end=752
  _globals['_SECRET_LABELSENTRY']._serialized_start=608
  _globals['_SECRET_LABELSENTRY']._serialized_end=653
  _globals['_SECRET_STATUS']._serialized_start=655
  _globals['_SECRET_STATUS']._serialized_end=727
  _globals['_VERSION']._serialized_start=755
  _globals['_VERSION']._serialized_end=1211
  _globals['_VERSION_STATUS']._serialized_start=1096
  _globals['_VERSION_STATUS']._serialized_end=1186
  _globals['_PASSWORDPAYLOADSPECIFICATION']._serialized_start=1214
  _globals['_PASSWORDPAYLOADSPECIFICATION']._serialized_end=1630
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.dataproc.v1.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Role:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Role.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ROLE_UNSPECIFIED: _Role.ValueType  # 0
    MASTERNODE: _Role.ValueType  # 1
    """The subcluster fulfills the master role.

    Master can run the following services, depending on the requested components:
    * HDFS: Namenode, Secondary Namenode
    * YARN: ResourceManager, Timeline Server
    * HBase Master
    * Hive: Server, Metastore, HCatalog
    * Spark History Server
    * Zeppelin
    * ZooKeeper
    """
    DATANODE: _Role.ValueType  # 2
    """The subcluster is a DATANODE in a Data Proc cluster.

    DATANODE can run the following services, depending on the requested components:
    * HDFS DataNode
    * YARN NodeManager
    * HBase RegionServer
    * Spark libraries
    """
    COMPUTENODE: _Role.ValueType  # 3
    """The subcluster is a COMPUTENODE in a Data Proc cluster.

    COMPUTENODE can run the following services, depending on the requested components:
    * YARN NodeManager
    * Spark libraries
    """

class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...

ROLE_UNSPECIFIED: Role.ValueType  # 0
MASTERNODE: Role.ValueType  # 1
"""The subcluster fulfills the master role.

Master can run the following services, depending on the requested components:
* HDFS: Namenode, Secondary Namenode
* YARN: ResourceManager, Timeline Server
* HBase Master
* Hive: Server, Metastore, HCatalog
* Spark History Server
* Zeppelin
* ZooKeeper
"""
DATANODE: Role.ValueType  # 2
"""The subcluster is a DATANODE in a Data Proc cluster.

DATANODE can run the following services, depending on the requested components:
* HDFS DataNode
* YARN NodeManager
* HBase RegionServer
* Spark libraries
"""
COMPUTENODE: Role.ValueType  # 3
"""The subcluster is a COMPUTENODE in a Data Proc cluster.

COMPUTENODE can run the following services, depending on the requested components:
* YARN NodeManager
* Spark libraries
"""
global___Role = Role

@typing.final
class AutoscalingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_HOSTS_COUNT_FIELD_NUMBER: builtins.int
    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    MEASUREMENT_DURATION_FIELD_NUMBER: builtins.int
    WARMUP_DURATION_FIELD_NUMBER: builtins.int
    STABILIZATION_DURATION_FIELD_NUMBER: builtins.int
    CPU_UTILIZATION_TARGET_FIELD_NUMBER: builtins.int
    DECOMMISSION_TIMEOUT_FIELD_NUMBER: builtins.int
    max_hosts_count: builtins.int
    """Upper limit for total instance subcluster count."""
    preemptible: builtins.bool
    """Preemptible instances are stopped at least once every 24 hours, and can be stopped at any time
    if their resources are needed by Compute.
    For more information, see [Preemptible Virtual Machines](/docs/compute/concepts/preemptible-vm).
    """
    cpu_utilization_target: builtins.float
    """Defines an autoscaling rule based on the average CPU utilization of the instance group."""
    decommission_timeout: builtins.int
    """Timeout to gracefully decommission nodes during downscaling. In seconds. Default value: 120"""
    @property
    def measurement_duration(self) -> google.protobuf.duration_pb2.Duration:
        """Time in seconds allotted for averaging metrics."""

    @property
    def warmup_duration(self) -> google.protobuf.duration_pb2.Duration:
        """The warmup time of the instance in seconds. During this time,
        traffic is sent to the instance, but instance metrics are not collected.
        """

    @property
    def stabilization_duration(self) -> google.protobuf.duration_pb2.Duration:
        """Minimum amount of time in seconds allotted for monitoring before
        Instance Groups can reduce the number of instances in the group.
        During this time, the group size doesn't decrease, even if the new metric values
        indicate that it should.
        """

    def __init__(
        self,
        *,
        max_hosts_count: builtins.int = ...,
        preemptible: builtins.bool = ...,
        measurement_duration: google.protobuf.duration_pb2.Duration | None = ...,
        warmup_duration: google.protobuf.duration_pb2.Duration | None = ...,
        stabilization_duration: google.protobuf.duration_pb2.Duration | None = ...,
        cpu_utilization_target: builtins.float = ...,
        decommission_timeout: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["measurement_duration", b"measurement_duration", "stabilization_duration", b"stabilization_duration", "warmup_duration", b"warmup_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cpu_utilization_target", b"cpu_utilization_target", "decommission_timeout", b"decommission_timeout", "max_hosts_count", b"max_hosts_count", "measurement_duration", b"measurement_duration", "preemptible", b"preemptible", "stabilization_duration", b"stabilization_duration", "warmup_duration", b"warmup_duration"]) -> None: ...

global___AutoscalingConfig = AutoscalingConfig

@typing.final
class Subcluster(google.protobuf.message.Message):
    """A Data Proc subcluster. For details about the concept, see [documentation](/docs/data-proc/concepts/)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    HOSTS_COUNT_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    AUTOSCALING_CONFIG_FIELD_NUMBER: builtins.int
    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the subcluster. Generated at creation time."""
    cluster_id: builtins.str
    """ID of the Data Proc cluster that the subcluster belongs to."""
    name: builtins.str
    """Name of the subcluster. The name is unique within the cluster."""
    role: global___Role.ValueType
    """Role that is fulfilled by hosts of the subcluster."""
    subnet_id: builtins.str
    """ID of the VPC subnet used for hosts in the subcluster."""
    hosts_count: builtins.int
    """Number of hosts in the subcluster."""
    assign_public_ip: builtins.bool
    """Assign public ip addresses for all hosts in subcluter."""
    instance_group_id: builtins.str
    """ID of Compute Instance Group for autoscaling subclusters"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def resources(self) -> yandex.cloud.dataproc.v1.common_pb2.Resources:
        """Resources allocated for each host in the subcluster."""

    @property
    def autoscaling_config(self) -> global___AutoscalingConfig:
        """Configuration for instance group based subclusters"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cluster_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        role: global___Role.ValueType = ...,
        resources: yandex.cloud.dataproc.v1.common_pb2.Resources | None = ...,
        subnet_id: builtins.str = ...,
        hosts_count: builtins.int = ...,
        assign_public_ip: builtins.bool = ...,
        autoscaling_config: global___AutoscalingConfig | None = ...,
        instance_group_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["autoscaling_config", b"autoscaling_config", "created_at", b"created_at", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "autoscaling_config", b"autoscaling_config", "cluster_id", b"cluster_id", "created_at", b"created_at", "hosts_count", b"hosts_count", "id", b"id", "instance_group_id", b"instance_group_id", "name", b"name", "resources", b"resources", "role", b"role", "subnet_id", b"subnet_id"]) -> None: ...

global___Subcluster = Subcluster

@typing.final
class Host(google.protobuf.message.Message):
    """A Data Proc host. For details about the concept, see [documentation](/docs/data-proc/concepts/)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SUBCLUSTER_ID_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the Data Proc host. The host name is assigned by Data Proc at creation time
    and cannot be changed. The name is generated to be unique across all Data Proc
    hosts that exist on the platform, as it defines the FQDN of the host.
    """
    subcluster_id: builtins.str
    """ID of the Data Proc subcluster that the host belongs to."""
    health: yandex.cloud.dataproc.v1.common_pb2.Health.ValueType
    """Status code of the aggregated health of the host."""
    compute_instance_id: builtins.str
    """ID of the Compute virtual machine that is used as the Data Proc host."""
    role: global___Role.ValueType
    """Role of the host in the cluster."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        subcluster_id: builtins.str = ...,
        health: yandex.cloud.dataproc.v1.common_pb2.Health.ValueType = ...,
        compute_instance_id: builtins.str = ...,
        role: global___Role.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "health", b"health", "name", b"name", "role", b"role", "subcluster_id", b"subcluster_id"]) -> None: ...

global___Host = Host



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/workflows/v1/execution_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.serverless.workflows.v1 import execution_pb2 as yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__pb2
from yandex.cloud.serverless.workflows.v1 import history_entry_pb2 as yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_history__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/serverless/workflows/v1/execution_service.proto\x12$yandex.cloud.serverless.workflows.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x34yandex/cloud/serverless/workflows/v1/execution.proto\x1a\x38yandex/cloud/serverless/workflows/v1/history_entry.proto\x1a\x1dyandex/cloud/validation.proto\"}\n\x15StartExecutionRequest\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x43\n\x05input\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.serverless.workflows.v1.ExecutionInputJ\x04\x08\x02\x10\x03\".\n\x16StartExecutionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"2\n\x14StopExecutionRequest\x12\x1a\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"-\n\x15StopExecutionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"7\n\x19TerminateExecutionRequest\x12\x1a\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"2\n\x1aTerminateExecutionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"1\n\x13GetExecutionRequest\x12\x1a\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"Z\n\x14GetExecutionResponse\x12\x42\n\texecution\x18\x01 \x01(\x0b\x32/.yandex.cloud.serverless.workflows.v1.Execution\"8\n\x1aGetExecutionHistoryRequest\x12\x1a\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xb5\x01\n\x1bGetExecutionHistoryResponse\x12I\n\texecution\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.serverless.workflows.v1.ExecutionPreview\x12K\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x32.yandex.cloud.serverless.workflows.v1.HistoryEntryB\x06\x82\xc8\x31\x02>0\"{\n\x15ListExecutionsRequest\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12#\n\tpage_size\x18\x02 \x01(\x03\x42\x10\xfa\xc7\x31\x0c\x30-2147483647\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"}\n\x16ListExecutionsResponse\x12J\n\nexecutions\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.serverless.workflows.v1.ExecutionPreview\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe3\x08\n\x10\x45xecutionService\x12\xac\x01\n\x05Start\x12;.yandex.cloud.serverless.workflows.v1.StartExecutionRequest\x1a<.yandex.cloud.serverless.workflows.v1.StartExecutionResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/workflows/v1/execution/start:\x01*\x12\xb4\x01\n\x04Stop\x12:.yandex.cloud.serverless.workflows.v1.StopExecutionRequest\x1a;.yandex.cloud.serverless.workflows.v1.StopExecutionResponse\"3\x82\xd3\xe4\x93\x02-\"+/workflows/v1/execution/{execution_id}/stop\x12\xc8\x01\n\tTerminate\x12?.yandex.cloud.serverless.workflows.v1.TerminateExecutionRequest\x1a@.yandex.cloud.serverless.workflows.v1.TerminateExecutionResponse\"8\x82\xd3\xe4\x93\x02\x32\"0/workflows/v1/execution/{execution_id}/terminate\x12\xac\x01\n\x03Get\x12\x39.yandex.cloud.serverless.workflows.v1.GetExecutionRequest\x1a:.yandex.cloud.serverless.workflows.v1.GetExecutionResponse\".\x82\xd3\xe4\x93\x02(\x12&/workflows/v1/execution/{execution_id}\x12\xc9\x01\n\nGetHistory\x12@.yandex.cloud.serverless.workflows.v1.GetExecutionHistoryRequest\x1a\x41.yandex.cloud.serverless.workflows.v1.GetExecutionHistoryResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./workflows/v1/execution/{execution_id}/history\x12\xa2\x01\n\x04List\x12;.yandex.cloud.serverless.workflows.v1.ListExecutionsRequest\x1a<.yandex.cloud.serverless.workflows.v1.ListExecutionsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/workflows/v1/executionB~\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflowsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.workflows.v1.execution_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflows'
  _STARTEXECUTIONREQUEST.fields_by_name['workflow_id']._options = None
  _STARTEXECUTIONREQUEST.fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _STOPEXECUTIONREQUEST.fields_by_name['execution_id']._options = None
  _STOPEXECUTIONREQUEST.fields_by_name['execution_id']._serialized_options = b'\350\3071\001'
  _TERMINATEEXECUTIONREQUEST.fields_by_name['execution_id']._options = None
  _TERMINATEEXECUTIONREQUEST.fields_by_name['execution_id']._serialized_options = b'\350\3071\001'
  _GETEXECUTIONREQUEST.fields_by_name['execution_id']._options = None
  _GETEXECUTIONREQUEST.fields_by_name['execution_id']._serialized_options = b'\350\3071\001'
  _GETEXECUTIONHISTORYREQUEST.fields_by_name['execution_id']._options = None
  _GETEXECUTIONHISTORYREQUEST.fields_by_name['execution_id']._serialized_options = b'\350\3071\001'
  _GETEXECUTIONHISTORYRESPONSE.fields_by_name['entries']._options = None
  _GETEXECUTIONHISTORYRESPONSE.fields_by_name['entries']._serialized_options = b'\202\3101\002>0'
  _LISTEXECUTIONSREQUEST.fields_by_name['workflow_id']._options = None
  _LISTEXECUTIONSREQUEST.fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _LISTEXECUTIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTEXECUTIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0140-2147483647'
  _EXECUTIONSERVICE.methods_by_name['Start']._options = None
  _EXECUTIONSERVICE.methods_by_name['Start']._serialized_options = b'\202\323\344\223\002\"\"\035/workflows/v1/execution/start:\001*'
  _EXECUTIONSERVICE.methods_by_name['Stop']._options = None
  _EXECUTIONSERVICE.methods_by_name['Stop']._serialized_options = b'\202\323\344\223\002-\"+/workflows/v1/execution/{execution_id}/stop'
  _EXECUTIONSERVICE.methods_by_name['Terminate']._options = None
  _EXECUTIONSERVICE.methods_by_name['Terminate']._serialized_options = b'\202\323\344\223\0022\"0/workflows/v1/execution/{execution_id}/terminate'
  _EXECUTIONSERVICE.methods_by_name['Get']._options = None
  _EXECUTIONSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/workflows/v1/execution/{execution_id}'
  _EXECUTIONSERVICE.methods_by_name['GetHistory']._options = None
  _EXECUTIONSERVICE.methods_by_name['GetHistory']._serialized_options = b'\202\323\344\223\0020\022./workflows/v1/execution/{execution_id}/history'
  _EXECUTIONSERVICE.methods_by_name['List']._options = None
  _EXECUTIONSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/workflows/v1/execution'
  _globals['_STARTEXECUTIONREQUEST']._serialized_start=275
  _globals['_STARTEXECUTIONREQUEST']._serialized_end=400
  _globals['_STARTEXECUTIONRESPONSE']._serialized_start=402
  _globals['_STARTEXECUTIONRESPONSE']._serialized_end=448
  _globals['_STOPEXECUTIONREQUEST']._serialized_start=450
  _globals['_STOPEXECUTIONREQUEST']._serialized_end=500
  _globals['_STOPEXECUTIONRESPONSE']._serialized_start=502
  _globals['_STOPEXECUTIONRESPONSE']._serialized_end=547
  _globals['_TERMINATEEXECUTIONREQUEST']._serialized_start=549
  _globals['_TERMINATEEXECUTIONREQUEST']._serialized_end=604
  _globals['_TERMINATEEXECUTIONRESPONSE']._serialized_start=606
  _globals['_TERMINATEEXECUTIONRESPONSE']._serialized_end=656
  _globals['_GETEXECUTIONREQUEST']._serialized_start=658
  _globals['_GETEXECUTIONREQUEST']._serialized_end=707
  _globals['_GETEXECUTIONRESPONSE']._serialized_start=709
  _globals['_GETEXECUTIONRESPONSE']._serialized_end=799
  _globals['_GETEXECUTIONHISTORYREQUEST']._serialized_start=801
  _globals['_GETEXECUTIONHISTORYREQUEST']._serialized_end=857
  _globals['_GETEXECUTIONHISTORYRESPONSE']._serialized_start=860
  _globals['_GETEXECUTIONHISTORYRESPONSE']._serialized_end=1041
  _globals['_LISTEXECUTIONSREQUEST']._serialized_start=1043
  _globals['_LISTEXECUTIONSREQUEST']._serialized_end=1166
  _globals['_LISTEXECUTIONSRESPONSE']._serialized_start=1168
  _globals['_LISTEXECUTIONSRESPONSE']._serialized_end=1293
  _globals['_EXECUTIONSERVICE']._serialized_start=1296
  _globals['_EXECUTIONSERVICE']._serialized_end=2419
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.serverless.workflows.v1 import execution_service_pb2 as yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2


class ExecutionServiceStub(object):
    """Set of methods for managing Workflows Executions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Start = channel.unary_unary(
                '/yandex.cloud.serverless.workflows.v1.ExecutionService/Start',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StartExecutionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StartExecutionResponse.FromString,
                )
        self.Stop = channel.unary_unary(
                '/yandex.cloud.serverless.workflows.v1.ExecutionService/Stop',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StopExecutionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StopExecutionResponse.FromString,
                )
        self.Terminate = channel.unary_unary(
                '/yandex.cloud.serverless.workflows.v1.ExecutionService/Terminate',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.TerminateExecutionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.TerminateExecutionResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.serverless.workflows.v1.ExecutionService/Get',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionResponse.FromString,
                )
        self.GetHistory = channel.unary_unary(
                '/yandex.cloud.serverless.workflows.v1.ExecutionService/GetHistory',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionHistoryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionHistoryResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.serverless.workflows.v1.ExecutionService/List',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.ListExecutionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.ListExecutionsResponse.FromString,
                )


class ExecutionServiceServicer(object):
    """Set of methods for managing Workflows Executions.
    """

    def Start(self, request, context):
        """Starts new Workflow execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Stops specified Workflow execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Terminate(self, request, context):
        """Terminates specified Workflow execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Retrieves specified Workflow execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHistory(self, request, context):
        """Retrieves detailed history of specified Workflow execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves list of Workflow executions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExecutionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StartExecutionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StartExecutionResponse.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StopExecutionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StopExecutionResponse.SerializeToString,
            ),
            'Terminate': grpc.unary_unary_rpc_method_handler(
                    servicer.Terminate,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.TerminateExecutionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.TerminateExecutionResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionResponse.SerializeToString,
            ),
            'GetHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHistory,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionHistoryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionHistoryResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.ListExecutionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.ListExecutionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.serverless.workflows.v1.ExecutionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ExecutionService(object):
    """Set of methods for managing Workflows Executions.
    """

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.workflows.v1.ExecutionService/Start',
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StartExecutionRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StartExecutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.workflows.v1.ExecutionService/Stop',
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StopExecutionRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.StopExecutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Terminate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.workflows.v1.ExecutionService/Terminate',
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.TerminateExecutionRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.TerminateExecutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.workflows.v1.ExecutionService/Get',
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.workflows.v1.ExecutionService/GetHistory',
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionHistoryRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.GetExecutionHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.workflows.v1.ExecutionService/List',
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.ListExecutionsRequest.SerializeToString,
            yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_execution__service__pb2.ListExecutionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/video.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!yandex/cloud/video/v1/video.proto\x12\x15yandex.cloud.video.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\x08\n\x05Video\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0cthumbnail_id\x18\x05 \x01(\t\x12\x38\n\x06status\x18\x06 \x01(\x0e\x32(.yandex.cloud.video.v1.Video.VideoStatus\x12+\n\x08\x64uration\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12H\n\x11visibility_status\x18\t \x01(\x0e\x32-.yandex.cloud.video.v1.Video.VisibilityStatus\x12<\n\x0e\x61uto_transcode\x18\x0b \x01(\x0e\x32$.yandex.cloud.video.v1.AutoTranscode\x12\x14\n\x0csubtitle_ids\x18\x0c \x03(\t\x12\x37\n\x04tusd\x18\xe8\x07 \x01(\x0b\x32&.yandex.cloud.video.v1.VideoTUSDSourceH\x00\x12H\n\rpublic_access\x18\xd0\x0f \x01(\x0b\x32..yandex.cloud.video.v1.VideoPublicAccessRightsH\x01\x12Q\n\x12\x61uth_system_access\x18\xd2\x0f \x01(\x0b\x32\x32.yandex.cloud.video.v1.VideoAuthSystemAccessRightsH\x01\x12K\n\x0fsign_url_access\x18\xd3\x0f \x01(\x0b\x32/.yandex.cloud.video.v1.VideoSignURLAccessRightsH\x01\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x06labels\x18\xc8\x01 \x03(\x0b\x32(.yandex.cloud.video.v1.Video.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x0bVideoStatus\x12\x1c\n\x18VIDEO_STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0eWAIT_UPLOADING\x10\x01\x12\x0e\n\nPROCESSING\x10\x04\x12\t\n\x05READY\x10\x05\x12\t\n\x05\x45RROR\x10\x07\"\x04\x08\x06\x10\x06\"U\n\x10VisibilityStatus\x12!\n\x1dVISIBILITY_STATUS_UNSPECIFIED\x10\x00\x12\r\n\tPUBLISHED\x10\x01\x12\x0f\n\x0bUNPUBLISHED\x10\x02\x42\x08\n\x06sourceB\x0f\n\raccess_rightsJ\x06\x08\xd1\x0f\x10\xd2\x0fJ\x04\x08\x07\x10\x08J\x04\x08\n\x10\x0bJ\x04\x08\r\x10\x64J\x05\x08\x66\x10\xc8\x01J\x06\x08\xc9\x01\x10\xe8\x07J\x06\x08\xe9\x07\x10\xd0\x0f\"\x1e\n\x0fVideoTUSDSource\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x19\n\x17VideoPublicAccessRights\"\x1d\n\x1bVideoAuthSystemAccessRights\"\x1a\n\x18VideoSignURLAccessRights*H\n\rAutoTranscode\x12\x1e\n\x1a\x41UTO_TRANSCODE_UNSPECIFIED\x10\x00\x12\n\n\x06\x45NABLE\x10\x01\x12\x0b\n\x07\x44ISABLE\x10\x02\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.video_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _VIDEO_LABELSENTRY._options = None
  _VIDEO_LABELSENTRY._serialized_options = b'8\001'
  _globals['_AUTOTRANSCODE']._serialized_start=1369
  _globals['_AUTOTRANSCODE']._serialized_end=1441
  _globals['_VIDEO']._serialized_start=126
  _globals['_VIDEO']._serialized_end=1249
  _globals['_VIDEO_LABELSENTRY']._serialized_start=932
  _globals['_VIDEO_LABELSENTRY']._serialized_end=977
  _globals['_VIDEO_VIDEOSTATUS']._serialized_start=979
  _globals['_VIDEO_VIDEOSTATUS']._serialized_end=1086
  _globals['_VIDEO_VISIBILITYSTATUS']._serialized_start=1088
  _globals['_VIDEO_VISIBILITYSTATUS']._serialized_end=1173
  _globals['_VIDEOTUSDSOURCE']._serialized_start=1251
  _globals['_VIDEOTUSDSOURCE']._serialized_end=1281
  _globals['_VIDEOPUBLICACCESSRIGHTS']._serialized_start=1283
  _globals['_VIDEOPUBLICACCESSRIGHTS']._serialized_end=1308
  _globals['_VIDEOAUTHSYSTEMACCESSRIGHTS']._serialized_start=1310
  _globals['_VIDEOAUTHSYSTEMACCESSRIGHTS']._serialized_end=1339
  _globals['_VIDEOSIGNURLACCESSRIGHTS']._serialized_start=1341
  _globals['_VIDEOSIGNURLACCESSRIGHTS']._serialized_end=1367
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    """A Kafka user.
    For more information, see the [Operations -> Accounts](/docs/managed-kafka/operations/cluster-accounts) section of the documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the Kafka user."""
    cluster_id: builtins.str
    """ID of the Apache Kafka® cluster the user belongs to.

    To get the Apache Kafka® cluster ID, make a [ClusterService.List] request.
    """
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions granted to this user."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "permissions", b"permissions"]) -> None: ...

global___User = User

@typing.final
class UserSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the Kafka user."""
    password: builtins.str
    """Password of the Kafka user."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions granted to the user."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        password: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "password", b"password", "permissions", b"permissions"]) -> None: ...

global___UserSpec = UserSpec

@typing.final
class Permission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AccessRole:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AccessRoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Permission._AccessRole.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACCESS_ROLE_UNSPECIFIED: Permission._AccessRole.ValueType  # 0
        ACCESS_ROLE_PRODUCER: Permission._AccessRole.ValueType  # 1
        """Producer role for the user."""
        ACCESS_ROLE_CONSUMER: Permission._AccessRole.ValueType  # 2
        """Consumer role for the user."""
        ACCESS_ROLE_ADMIN: Permission._AccessRole.ValueType  # 3
        """Admin role for the user."""

    class AccessRole(_AccessRole, metaclass=_AccessRoleEnumTypeWrapper): ...
    ACCESS_ROLE_UNSPECIFIED: Permission.AccessRole.ValueType  # 0
    ACCESS_ROLE_PRODUCER: Permission.AccessRole.ValueType  # 1
    """Producer role for the user."""
    ACCESS_ROLE_CONSUMER: Permission.AccessRole.ValueType  # 2
    """Consumer role for the user."""
    ACCESS_ROLE_ADMIN: Permission.AccessRole.ValueType  # 3
    """Admin role for the user."""

    TOPIC_NAME_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    ALLOW_HOSTS_FIELD_NUMBER: builtins.int
    topic_name: builtins.str
    """Name or prefix-pattern with wildcard for the topic that the permission grants access to.

    To get the topic name, make a [TopicService.List] request.
    """
    role: global___Permission.AccessRole.ValueType
    """Access role type to grant to the user."""
    @property
    def allow_hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Lists hosts allowed for this permission.
        Only ip-addresses allowed as value of single host.
        When not defined, access from any host is allowed.

        Bare in mind that the same host might appear in multiple permissions at the same time,
        hence removing individual permission doesn't automatically restricts access from the [allow_hosts] of the permission.
        If the same host(s) is listed for another permission of the same principal/topic, the host(s) remains allowed.
        """

    def __init__(
        self,
        *,
        topic_name: builtins.str = ...,
        role: global___Permission.AccessRole.ValueType = ...,
        allow_hosts: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["allow_hosts", b"allow_hosts", "role", b"role", "topic_name", b"topic_name"]) -> None: ...

global___Permission = Permission



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tuning/v1/tuning_optimizers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/ai/tuning/v1/tuning_optimizers.proto\x12\x19yandex.cloud.ai.tuning.v1\"Q\n\x0eOptimizerAdamw\x12\r\n\x05\x62\x65ta1\x18\x01 \x01(\x01\x12\r\n\x05\x62\x65ta2\x18\x02 \x01(\x01\x12\x0b\n\x03\x65ps\x18\x03 \x01(\x01\x12\x14\n\x0cweight_decay\x18\x04 \x01(\x01\x42\x63\n\x1dyandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tuning.v1.tuning_optimizers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomo'
  _globals['_OPTIMIZERADAMW']._serialized_start=80
  _globals['_OPTIMIZERADAMW']._serialized_end=161
# @@protoc_insertion_point(module_scope)
